@@ -39,17 +39,18 @@ try:
 except ImportError:
     HAS_DATEUTIL = False
 
-try:
-    import numpy # pylint: disable=unused-import
-    HAS_NUMPY = True
-except ImportError:
-    HAS_NUMPY = False
-
 try:
     import pytest
     HAS_PYTEST = True
 except ImportError:
     HAS_PYTEST = False
+
+try:
+    import attr as attr_module # pylint: disable=unused-import
+    HAS_ATTR = True
+except ImportError:
+    HAS_ATTR = False
+
 import six
 
 from astroid import MANAGER
@@ -79,6 +80,27 @@ class HashlibTest(unittest.TestCase):
             self.assertEqual(len(class_obj['hexdigest'].args.args), 1)
 
 
+class CollectionsDequeTests(unittest.TestCase):
+    def _inferred_queue_instance(self):
+        node = builder.extract_node("""
+        import collections
+        q = collections.deque([])
+        q
+        """)
+        return next(node.infer())
+
+    def test_deque(self):
+        inferred = self._inferred_queue_instance()
+        self.assertTrue(inferred.getattr('__len__'))
+
+    @test_utils.require_version(minver='3.5')
+    def test_deque_py35methods(self):
+        inferred = self._inferred_queue_instance()
+        self.assertIn('copy', inferred.locals)
+        self.assertIn('insert', inferred.locals)
+        self.assertIn('index', inferred.locals)
+
+
 class NamedTupleTest(unittest.TestCase):
 
     def test_namedtuple_base(self):
@@ -193,6 +215,30 @@ class NamedTupleTest(unittest.TestCase):
         self.assertIn('b', inferred.locals)
         self.assertIn('c', inferred.locals)
 
+    def test_namedtuple_func_form(self):
+        node = builder.extract_node("""
+        from collections import namedtuple
+        Tuple = namedtuple(typename="Tuple", field_names="a b c", rename=UNINFERABLE)
+        Tuple #@
+        """)
+        inferred = next(node.infer())
+        self.assertEqual(inferred.name, 'Tuple')
+        self.assertIn('a', inferred.locals)
+        self.assertIn('b', inferred.locals)
+        self.assertIn('c', inferred.locals)
+
+    def test_namedtuple_func_form_args_and_kwargs(self):
+        node = builder.extract_node("""
+        from collections import namedtuple
+        Tuple = namedtuple("Tuple", field_names="a b c", rename=UNINFERABLE)
+        Tuple #@
+        """)
+        inferred = next(node.infer())
+        self.assertEqual(inferred.name, 'Tuple')
+        self.assertIn('a', inferred.locals)
+        self.assertIn('b', inferred.locals)
+        self.assertIn('c', inferred.locals)
+
 
 class DefaultDictTest(unittest.TestCase):
 
@@ -415,20 +461,33 @@ class MultiprocessingBrainTest(unittest.TestCase):
         self.assertTrue(manager.getattr('start'))
         self.assertTrue(manager.getattr('shutdown'))
 
-class ThreadingBrainTest(unittest.TestCase):
 
-    def test_threading(self):
-        module = builder.extract_node("""
+class ThreadingBrainTest(unittest.TestCase):
+    def test_lock(self):
+        self._test_lock_object('Lock')
+
+    def test_rlock(self):
+        self._test_lock_object('RLock')
+
+    def test_semaphore(self):
+        self._test_lock_object('Semaphore')
+
+    def test_boundedsemaphore(self):
+        self._test_lock_object('BoundedSemaphore')
+
+    def _test_lock_object(self, object_name):
+        lock_instance = builder.extract_node("""
         import threading
-        threading.Lock()
-        """)
-        inferred = next(module.infer())
+        threading.{0}()
+        """.format(object_name))
+        inferred = next(lock_instance.infer())
+        self.assert_is_valid_lock(inferred)
+
+    def assert_is_valid_lock(self, inferred):
         self.assertIsInstance(inferred, astroid.Instance)
         self.assertEqual(inferred.root().name, 'threading')
-        self.assertIsInstance(inferred.getattr('acquire')[0],
-                              astroid.FunctionDef)
-        self.assertIsInstance(inferred.getattr('release')[0],
-                              astroid.FunctionDef)
+        for method in {'acquire', 'release', '__enter__', '__exit__'}:
+            self.assertIsInstance(next(inferred.igetattr(method)), astroid.BoundMethod)
 
 
 @unittest.skipUnless(HAS_ENUM,
@@ -521,6 +580,40 @@ class EnumBrainTest(unittest.TestCase):
         self.assertIsInstance(next(inferred_instance.igetattr('name')), nodes.Const)
         self.assertIsInstance(next(inferred_instance.igetattr('value')), nodes.Const)
 
+    def test_enum_func_form_iterable(self):
+        instance = builder.extract_node('''
+        from enum import Enum
+        Animal = Enum('Animal', 'ant bee cat dog')
+        Animal
+        ''')
+        inferred = next(instance.infer())
+        self.assertIsInstance(inferred, astroid.Instance)
+        self.assertTrue(inferred.getattr('__iter__'))
+
+    def test_enum_func_form_subscriptable(self):
+        instance, name = builder.extract_node('''
+        from enum import Enum
+        Animal = Enum('Animal', 'ant bee cat dog')
+        Animal['ant'] #@
+        Animal['ant'].name #@
+        ''')
+        instance = next(instance.infer())
+        self.assertIsInstance(instance, astroid.Instance)
+
+        inferred = next(name.infer())
+        self.assertIsInstance(inferred, astroid.Const)
+
+    def test_enum_func_form_has_dunder_members(self):
+        instance = builder.extract_node('''
+        from enum import Enum
+        Animal = Enum('Animal', 'ant bee cat dog')
+        for i in Animal.__members__:
+            i #@
+        ''')
+        instance = next(instance.infer())
+        self.assertIsInstance(instance, astroid.Const)
+        self.assertIsInstance(instance.value, str)
+
 
 @unittest.skipUnless(HAS_DATEUTIL, "This test requires the dateutil library.")
 class DateutilBrainTest(unittest.TestCase):
@@ -533,18 +626,6 @@ class DateutilBrainTest(unittest.TestCase):
         self.assertEqual(d_type.qname(), "datetime.datetime")
 
 
-@unittest.skipUnless(HAS_NUMPY, "This test requires the numpy library.")
-class NumpyBrainTest(unittest.TestCase):
-
-    def test_numpy(self):
-        node = builder.extract_node('''
-        import numpy
-        numpy.ones #@
-        ''')
-        inferred = next(node.infer())
-        self.assertIsInstance(inferred, nodes.FunctionDef)
-
-
 @unittest.skipUnless(HAS_PYTEST, "This test requires the pytest library.")
 class PytestBrainTest(unittest.TestCase):
 
@@ -681,5 +762,68 @@ class ReBrainTest(unittest.TestCase):
             self.assertEqual(next(re_ast[name].infer()).value, getattr(re, name))
 
 
+@test_utils.require_version('3.6')
+class BrainFStrings(unittest.TestCase):
+
+    def test_no_crash_on_const_reconstruction(self):
+        node = builder.extract_node('''
+        max_width = 10
+
+        test1 = f'{" ":{max_width+4}}'
+        print(f'"{test1}"')
+
+        test2 = f'[{"7":>{max_width}}:0]'
+        test2
+        ''')
+        inferred = next(node.infer())
+        self.assertIs(inferred, util.Uninferable)
+
+
+@test_utils.require_version('3.6')
+class BrainNamedtupleAnnAssignTest(unittest.TestCase):
+
+    def test_no_crash_on_ann_assign_in_namedtuple(self):
+        node = builder.extract_node('''
+        from enum import Enum
+        from typing import Optional
+
+        class A(Enum):
+            B: str = 'B'
+        ''')
+        inferred = next(node.infer())
+        self.assertIsInstance(inferred, nodes.ClassDef)
+
+
+class BrainUUIDTest(unittest.TestCase):
+
+    def test_uuid_has_int_member(self):
+        node = builder.extract_node('''
+        import uuid
+        u = uuid.UUID('{12345678-1234-5678-1234-567812345678}')
+        u.int
+        ''')
+        inferred = next(node.infer())
+        self.assertIsInstance(inferred, nodes.Const)
+
+
+@unittest.skipUnless(HAS_ATTR, "These tests require the attr library")
+class AttrsTest(unittest.TestCase):
+    def test_attr_transform(self):
+        module = astroid.parse("""
+        import attr
+
+        @attr.s
+        class Foo:
+
+            d = attr.ib(attr.Factory(dict))
+
+        f = Foo()
+        f.d['answer'] = 42
+        """)
+
+        should_be_attribute = next(module.getattr('f')[0].infer()).getattr('d')[0]
+        self.assertIsInstance(should_be_attribute, astroid.Unknown)
+
+
 if __name__ == '__main__':
     unittest.main()
