@@ -31,7 +31,7 @@ class InstanceModelTest(unittest.TestCase):
         a.__module__ #@
         a.__doc__ #@
         a.__dict__ #@
-        ''', module_name='collections')
+        ''', module_name='fake_module')
 
         cls = next(ast_nodes[0].infer())
         self.assertIsInstance(cls, astroid.ClassDef)
@@ -39,7 +39,7 @@ class InstanceModelTest(unittest.TestCase):
 
         module = next(ast_nodes[1].infer())
         self.assertIsInstance(module, astroid.Const)
-        self.assertEqual(module.value, 'collections')
+        self.assertEqual(module.value, 'fake_module')
 
         doc = next(ast_nodes[2].infer())
         self.assertIsInstance(doc, astroid.Const)
@@ -197,11 +197,11 @@ class ClassModelTest(unittest.TestCase):
         A.__class__ #@
         A.__dict__ #@
         A.__subclasses__() #@
-        ''', module_name='collections')
+        ''', module_name='fake_module')
 
         module = next(ast_nodes[0].infer())
         self.assertIsInstance(module, astroid.Const)
-        self.assertEqual(module.value, 'collections')
+        self.assertEqual(module.value, 'fake_module')
 
         name = next(ast_nodes[1].infer())
         self.assertIsInstance(name, astroid.Const)
@@ -209,7 +209,7 @@ class ClassModelTest(unittest.TestCase):
 
         qualname = next(ast_nodes[2].infer())
         self.assertIsInstance(qualname, astroid.Const)
-        self.assertEqual(qualname.value, 'collections.A')
+        self.assertEqual(qualname.value, 'fake_module.A')
 
         doc = next(ast_nodes[3].infer())
         self.assertIsInstance(doc, astroid.Const)
@@ -358,7 +358,7 @@ class FunctionModelTest(unittest.TestCase):
         func.__globals__ #@
         func.__code__ #@
         func.__closure__ #@
-        ''', module_name='collections')
+        ''', module_name='fake_module')
 
         name = next(ast_nodes[0].infer())
         self.assertIsInstance(name, astroid.Const)
@@ -370,11 +370,11 @@ class FunctionModelTest(unittest.TestCase):
 
         qualname = next(ast_nodes[2].infer())
         self.assertIsInstance(qualname, astroid.Const)
-        self.assertEqual(qualname.value, 'collections.func')
+        self.assertEqual(qualname.value, 'fake_module.func')
 
         module = next(ast_nodes[3].infer())
         self.assertIsInstance(module, astroid.Const)
-        self.assertEqual(module.value, 'collections')
+        self.assertEqual(module.value, 'fake_module')
 
         defaults = next(ast_nodes[4].infer())
         self.assertIsInstance(defaults, astroid.Tuple)
@@ -399,6 +399,18 @@ class FunctionModelTest(unittest.TestCase):
         self.assertIsInstance(annotations, astroid.Dict)
         self.assertEqual(len(annotations.items), 0)
 
+    @test_utils.require_version(minver='3.0')
+    def test_builtin_dunder_init_does_not_crash_when_accessing_annotations(self):
+        ast_node = builder.extract_node('''
+        class Class:
+            @classmethod
+            def class_method(cls):
+                cls.__init__.__annotations__ #@
+        ''')
+        inferred = next(ast_node.infer())
+        self.assertIsInstance(inferred, astroid.Dict)
+        self.assertEqual(len(inferred.items), 0)
+
     @test_utils.require_version(minver='3.0')
     def test_annotations_kwdefaults(self):
         ast_node = builder.extract_node('''
@@ -415,8 +427,7 @@ class FunctionModelTest(unittest.TestCase):
         self.assertEqual(annotations.getitem(astroid.Const('args')).value, 2)
         self.assertEqual(annotations.getitem(astroid.Const('kwarg')).value, 3)
 
-        # Currently not enabled.
-        # self.assertEqual(annotations.getitem('f').value, 4)
+        self.assertEqual(annotations.getitem(astroid.Const('f')).value, 4)
 
         kwdefaults = next(ast_node[1].infer())
         self.assertIsInstance(kwdefaults, astroid.Dict)
